/*
 * Copyright 2000, International Business Machines Corporation and others.
 * All Rights Reserved.
 *
 * This software has been released under the terms of the IBM Public
 * License.  For details, see the LICENSE file in the top-level source
 * directory or online at http://www.openafs.org/dl/license10.html
 */

#ifndef _BOSPROTOTYPES_H_
#define _BOSPROTOTYPES_H_

/* bosserver.c */
void bozo_Log(char *format, ... );

/* bosoprocs.c */
void *bozo_ShutdownAndExit(void *arock /* really int asignal */);

#endif
